@@ -10,7 +10,7 @@
 # 4) Overlap file extents
 # 5) Unable to rollback
 
-source $TOP/tests/common
+source "$TOP/tests/common"
 
 check_prereq btrfs-convert
 check_prereq btrfs
@@ -23,20 +23,20 @@ prepare_test_dev 512M
 # override common function
 function check_image() {
 	TEST_DEV="$1"
-	run_check e2fsck -n -f $TEST_DEV
-	run_check $TOP/btrfs-convert $TEST_DEV
-	run_check $TOP/btrfs check $TEST_DEV
-	run_check $TOP/btrfs inspect-internal dump-super $TEST_DEV
+	run_check e2fsck -n -f "$TEST_DEV"
+	run_check "$TOP/btrfs-convert" "$TEST_DEV"
+	run_check "$TOP/btrfs" check "$TEST_DEV"
+	run_check "$TOP/btrfs" inspect-internal dump-super "$TEST_DEV"
 
 	run_check_mount_test_dev
-	run_check $SUDO_HELPER e2fsck -n -f $TEST_MNT/ext2_saved/image
-	run_check $SUDO_HELPER umount $TEST_MNT
+	run_check $SUDO_HELPER e2fsck -n -f "$TEST_MNT/ext2_saved/image"
+	run_check $SUDO_HELPER umount "$TEST_MNT"
 
-	run_check $TOP/btrfs check $TEST_DEV
-	run_check $TOP/btrfs-convert -r $TEST_DEV
-	run_check e2fsck -n -f $TEST_DEV
+	run_check "$TOP/btrfs" check "$TEST_DEV"
+	run_check "$TOP/btrfs-convert" -r "$TEST_DEV"
+	run_check e2fsck -n -f "$TEST_DEV"
 
-	rm -f $TEST_DEV
+	rm -f "$TEST_DEV"
 }
 
 check_all_images
